This one is very weird. I'm investigating why a Kanban board is loading slowly, and I found something quite surprising: When using a project category as the basis of the JQL and then excluding specific projects and issue types, the board is a lot slower (several minutes) instead of 2-3 seconds. Here's how I went about this:
- category = [projectCategory] and type != [issuetype]: Fast (17k issues)
- category = [projectCategory] project != [projectName]: Fast (17k issues)
- category = [projectCategory] and type !=[issuetype] and project != [projectName]: Very slow!!! (16k issues)
This seems counterintuitive, since a more restrictive filter that returns fewer issues should load at least a tiny bit faster. I went and made more tests:
category = [projectCategory] project != [projectName] AND and type in ([all other issue types]): Fast (16k issues)
That's nonsensical, it's the results as the query that's slow, I just substituted the "type != [issuetype]" with a list of all issue types used in these projects.
Further tests:
- category = [projectCategory] and type != [issuetype] and status not in (done, closed): Very fast (1400 issues)
- category = [projectCategory] and type != [issuetype] and status not in (done, closed) AND project != [projectName] : Very slow (1200 issues)
In all these cases, the JQL itself is reasonably fast, 50-100ms. It's really the Kanban board loading that's affected by the JQL syntax more than by the number of results, and it's extremely weird. Anybody else has seen something like this? I couldn't find anything on Answers or in the Atlassian Jira.
Thanks,
Nicolas